# mlgenotype

This python package can be used to train machine learning models to genotype structural variants using aligned short read data. It was written by Nancy Fisher Hansen, a staff scientist in the Computational and Statistical Genomics Branch of NHGRI, beginning with code written by Gracelyn Hill and Jennifer C Lin.  Nancy can be reached at nhansen@mail.nih.gov.

## Software dependencies

- pandas >= 1.0
- scikit-learn == 1.0.2

## Clone the repository

	git clone git://github.com/nhansen/mlgenotype



